!-------------------------------------- LICENCE BEGIN ------------------------------------
!Environment Canada - Atmospheric Science and Technology License/Disclaimer, 
!                     version 3; Last Modified: May 7, 2008.
!This is free but copyrighted software; you can use/redistribute/modify it under the terms 
!of the Environment Canada - Atmospheric Science and Technology License/Disclaimer 
!version 3 or (at your option) any later version that should be found at: 
!http://collaboration.cmc.ec.gc.ca/science/rpn.comm/license.html 
!
!This software is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
!without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
!See the above mentioned License/Disclaimer for more details.
!You should have received a copy of the License/Disclaimer along with this software; 
!if not, you can write to: EC-RPN COMM Group, 2121 TransCanada, suite 500, Dorval (Quebec), 
!CANADA, H9P 1J3; or send e-mail to service.rpn@ec.gc.ca
!-------------------------------------- LICENCE END --------------------------------------
#if defined (DOC)
*
***comdeck cdmacro.cdk
*
*     Defini les variables necessaires pour le macrotasking
*
*      pnid : Le numero de tache assigne par le systeme
*      ptparm : Parametre reconnaissable par le macrotasking
*      ptcpu : Numero de tache logique correspondant a la pile
*
#endif
*
*   On place arbitrairement le nombre de cpu a 32.
*
       integer nmxcpu
       parameter ( nmxcpu = 32 )
*
*
#if defined (MULTI)
#if defined (NEC)
      integer icpu
      integer ptparm(nmxcpu)
      integer pnid(nmxcpu) , ptcpu(nmxcpu)
#endif
#endif